@@ -87,7 +87,7 @@
 #' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
 #'  "sen2r": An R toolbox for automatically downloading and preprocessing 
 #'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. 
-#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{http://sen2r.ranghetti.info/}.
+#'  \doi{10.1016/j.cageo.2020.104473}, URL: \url{https://sen2r.ranghetti.info/}.
 #' @note License: GPL 3.0
 #' @export
 #' @import data.table
@@ -121,7 +121,7 @@
 #' # Download a sample SAFE archive (this can take a while)
 #' s2_exampleurl <- c(
 #'   "S2A_MSIL1C_20190723T101031_N0208_R022_T32TNS_20190723T121220.SAFE" =
-#'     paste0("https://scihub.copernicus.eu/apihub/odata/v1/",
+#'     paste0("https://apihub.copernicus.eu/apihub/odata/v1/",
 #'            "Products('19bbde60-992b-423d-8dea-a5e0ac7715fc')/$value")
 #' )
 #' s2_download(s2_exampleurl, outdir=tempdir())
@@ -867,10 +867,16 @@ safe_isvalid <- function(
             matrix(sel_footprint_raw0, ncol = 2, byrow = TRUE)[,2:1],
             1, paste, collapse = " "
           )
-          metadata[[i]][["footprint"]] <-  paste0(
+          metadata[[i]][["footprint"]] <- paste0(
             "POLYGON((",
             paste(sel_footprint_raw1,  collapse = ", "),"))"
           )
+          if (any(!st_is_valid(st_as_sfc(metadata[[i]][["footprint"]], crs = 4326)))) {
+            metadata[[i]][["footprint"]] <- st_as_text(
+              st_make_valid(st_as_sfc(metadata[[i]][["footprint"]], crs = 4326)), 
+              digits = 9
+            )
+          }
         }
       }
       
