@@ -1,12 +1,7 @@
 # Retrieve Travis credentials
-tests_apihub <- if (Sys.getenv("TRAVIS") == "true") {c(
-  paste0("sen2r_travis_",Sys.getenv("TRAVIS_R_VERSION_STRING")),
-  Sys.getenv("TRAVIS_PASSWORD")
-)} else {
-  saved_creds <- try(sen2r::read_scihub_login(), silent = TRUE)
-}
+tests_apihub <- try(sen2r::read_scihub_login(), silent = TRUE)
 
-if (!inherits(saved_creds, "try-error")) {
+if (!inherits(tests_apihub, "try-error")) {
   
   # Use a temporary apihub file
   write_scihub_login(
