@@ -1,34 +1,26 @@
 message("\n---- Test ignorelist ----")
 testthat::skip_on_cran()
 testthat::skip_on_ci() # TODO try to remove
-testthat::skip_if_not(is_scihub_configured(), "SciHub credentials are not set")
+testthat::skip_if_not(is_gcloud_configured(), "Google account is not set")
+testthat::skip_if_not(check_gcloud_connection(), "Google Cloud server is not reachable")
 
 # Ensure required SAFE to be downloaded
 s2_l2a_list <- c(
-  "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNR_20200801T135302.SAFE" =
-    "https://apihub.copernicus.eu/apihub/odata/v1/Products('e502d496-631f-4557-b14f-d98195fdc8c1')/$value",
-  "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNS_20200801T135302.SAFE" =
-    "https://apihub.copernicus.eu/apihub/odata/v1/Products('4aac5270-bbdf-4743-9f9f-532fdbfea2fd')/$value"
+  "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNR_20200801T135302.SAFE",
+  "S2B_MSIL2A_20200801T100559_N0214_R022_T32TNS_20200801T135302.SAFE"
 )
-suppressWarnings(s2_l2a_downloaded <- s2_download(
-  s2_l2a_list,
-  downloader = "builtin",
-  outdir = safe_dir,
-  apihub = tests_apihub_path,
-  overwrite = FALSE
-))
 
 testthat::test_that(
   "Tests on safelist read/write", {
     
     # Check sample inputs
     testthat::skip_if_not(file.exists(file.path(
-      safe_dir, names(s2_l2a_list[1]),
+      safe_dir, s2_l2a_list[1],
       "GRANULE/L2A_T32TNR_A017780_20200801T101400/IMG_DATA/R10m",
       "T32TNR_20200801T100559_B08_10m.jp2"
     )))
     testthat::skip_if_not(file.exists(file.path(
-      safe_dir, names(s2_l2a_list[2]),
+      safe_dir, s2_l2a_list[2],
       "GRANULE/L2A_T32TNS_A017780_20200801T101400/IMG_DATA/R10m",
       "T32TNS_20200801T100559_B08_10m.jp2"
     )))
@@ -48,13 +40,12 @@ testthat::test_that(
       max_mask = 10,
       path_l2a = safe_dir,
       path_out = outdir_17,
-      thumbnails = FALSE,
-      apihub = tests_apihub_path
+      thumbnails = FALSE
     )
     
     ignorelist_path <- file.path(outdir_17, ".ignorelist.txt")
     expect_true(file.exists(ignorelist_path))
-    ignorelist <- parseTOML(ignorelist_path)
+    ignorelist <- RcppTOML::parseTOML(ignorelist_path)
     expect_length(ignorelist, 4)
     expect_equal(
       sort(names(ignorelist)), 
